Skip to contents

A list contains labels and one score column per class for a 3-class dataset. The three classes are separated to different degrees, so that a one-vs-rest evaluation of them shows three clearly different curves.

Usage

data(C3N150)

Format

A list with 2 items.

scores

a 150 by 3 matrix of scores, one column per class, with the column names 'c1', 'c2' and 'c3'

labels

150 labels as 'c1', 'c2' or 'c3', 50 of each